Contributing
============

Thanks for your interest! We love contributions, so please feel free to fix bugs, improve things, provide documentation. Just `follow the
guidelines <http://djangonauts.github.io/django-hstore/#_developers_guide>`_ and submit a PR.
